![img_1.png](img_1.png)

scEvoNet generates __cell state / gene__ network between species or different time points in the same organism using scRNA-seq matrices as an input.
### Installation
Install from [PyPI](https://pypi.org/project/scevonet)

``pip install scevonet``

### Usage Principles

Please have a look at the [guide jupyter notebook](https://github.com/Qotov/scEvoNet/blob/main/guide/HowToUse.ipynb)

 ###### Visit our lab [page](https://curie.fr/equipe/monsoro-burq) 
